%define _without_crippled_stk 1
#
# spec file for package lmms
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without distributable
%bcond_without crippled_stk

Name:           lmms
Version:        0.4.15
Release:        39.4
Summary:        Linux MultiMedia Studio
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Midi
Url:            http://lmms.sourceforge.net/
%if %{with distributable}
Source0:        lmms-%{version}-crippled.tar.bz2
%else
Source0:        http://downloads.sourceforge.net/lmms/lmms-%{version}.tar.bz2
%endif
Source1:        releasenotes-%{version}.txt
Source99:       precheckin_cripple_tarball.sh
Patch0:         lmms-0.4.14-system_fltk.patch
# PATCH-FIX-OPENSUSE Patch for providing proper return code in a function
Patch2:         lmms-0.4.12-return.patch
# PATCH-FIX-OPENSUSE Some parts cannot be build because stk misses some files due to legal issues (bnc#761147)
Patch4:         lmms-0.4.13-crippled_stk.patch
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libstk-devel
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtXml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3f)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(zlib)
%ifarch %ix86
BuildRequires:  wine-devel
%endif
%if 0%{?suse_version} > 1210
%ifarch x86_64
%if 0%{?suse_version} == 1230
# Workaround for missing dependency in wine-devel-32bit
BuildRequires:  wine-devel
%endif
BuildRequires:  gcc-c++-32bit
BuildRequires:  wine-devel-32bit
%endif
%endif
Recommends:     %{_bindir}/wine

%description
LMMS is a free cross-platform music studio which allows you to produce music
with your computer. This includes the creation of melodies and beats, the
synthesis and mixing of sounds, and arranging of samples.

%package devel
Summary:        Headers to create LMMS plugins
Group:          Development/Libraries/C and C++

%description devel
Headers that provide access to the LMMS features. Install it if you plan to
create a LMMS plugin.

%prep
%setup -q
%patch0
%patch2
%if %{with crippled_stk}
%patch4
%endif
# Ensure we use system fltk
rm -r plugins/zynaddsubfx/fltk

%build
mkdir build
cd build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
cmake -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
      -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DCMAKE_INSTALL_LIBDIR=%{_lib} \
      -DCMAKE_BUILD_TYPE=Release \
      -DCMAKE_VERBOSE_MAKEFILE=TRUE \
      ..
make %{?_smp_flags}

%install
cd build
%make_install
cd ..
# Debian menu system
rm -r '%{buildroot}%{_datadir}/menu'

mkdir -p '%{buildroot}%{_defaultdocdir}/lmms/'
cp %{S:1} '%{buildroot}%{_defaultdocdir}/lmms/'

%post
%icon_theme_cache_post
%mime_database_post
%desktop_database_post

%postun
%desktop_database_postun
%mime_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README TODO
%{_bindir}/lmms
%{_mandir}/man1/lmms.1*
%{_libdir}/lmms/
%{_datadir}/lmms/
%{_defaultdocdir}/lmms/releasenotes-%{version}.txt
%{_datadir}/applications/lmms.desktop
%{_datadir}/pixmaps/lmms.png
%{_datadir}/mime/packages/lmms.xml

%files devel
%defattr(0644,root,root,0755)
%{_includedir}/lmms/

%changelog
* Thu Aug  1 2013 reddwarf@opensuse.org
- Enable VST support in openSUSE 12.3 x86-64
* Wed Jun 12 2013 reddwarf@opensuse.org
- Update to 0.4.15
  * AutomationPattern: initialize with current value of first object
  * Chords: fixed major pentatonic
  * Properly cancel file export if opening output file failed
  * InstrumentTrack: fix freeze when forwarding MIDI events to instrument
  * Sf2Player: preserve custom track name when loading settings
  * AudioFileProcessor: make playback cursor configurable
  * AudioFileProcessor: fix crash with reversed samples
* Wed May  1 2013 reddwarf@opensuse.org
- Add lmms-0.4.14-system_fltk.patch.
- Stop building the portaudio and sdl audio backends. There is no
  need for wrappers when the real backends are directly supported.
- Remove one %%if. wine-32bit has never been a substitute for wine-devel-32bit.
- Use %%{_defaultdocdir} instead of {_datadir}/doc/packages
* Mon Apr 29 2013 stephan.barth@suse.com
- update to version 0.4.14 which is a maintainance release "with some exciting
  new features (notably regarding VST support)"
  Full upstream changelog can be found in
  /usr/share/doc/packages/lmms/releasenotes-0.4.14.txt
- removed the following patches because they have been applied upstream:
  - lmms-0.4.12-overflow.patch
  - lmms-0.4.13-gcc47.patch
- removed lmms-0.4.12-system_fltk.patch because the UI now fails to link with
  "undefined references" with the openSUSE fltk. Package now builds with fltk
  provided by its own tarball
* Tue Sep 11 2012 reddwarf@opensuse.org
- Recommend %%{_bindir}/wine, needed by the VST plugin
- Don't remove execute permission from VST and ZynAddSubFx plugins
- Don't remove rpath, it's needed by the ZynAddSubFx plugin
* Wed Aug 22 2012 dmueller@suse.com
- simply set libdir in the cmake call, which fixes build for ARM
* Mon Aug  6 2012 dvaleev@suse.com
- set libdir on powerpc correctly
* Wed May 16 2012 reddwarf@opensuse.org
- Fix build with openSUSE's crippled stk
* Tue May  8 2012 reddwarf@opensuse.org
- Add precheckin_cripple_tarball.sh logic (bnc#761147)
* Fri Apr 27 2012 reddwarf@opensuse.org
- Remove %%suse_update_desktop_file usage
- Add lmms-0.4.13-gcc47.patch
* Thu Mar  8 2012 reddwarf@opensuse.org
- Initial package
